@@ -2,11 +2,17 @@
 #include <pybind11/stl.h>
 #include "sim.h"
 
-HRESULT h;
-
 namespace py = pybind11;
 
 PYBIND11_MODULE(_native, m) {
+    py::register_exception_translator([](std::exception_ptr exc_ptr) {
+        try {
+            if (exc_ptr) std::rethrow_exception(exc_ptr);
+        } catch (const SimException &exc) {
+            PyErr_SetFromWindowsErr(exc.hresult);
+        }
+    });
+
     py::enum_<SIMCONNECT_EXCEPTION>(m, "EXCEPTION", py::arithmetic(), "SimConnect Exception")
     .value("NONE", SIMCONNECT_EXCEPTION_NONE)
     .value("ERROR", SIMCONNECT_EXCEPTION_ERROR)
