@@ -3,7 +3,7 @@
 #include "sim.h"
 
 void check_exc(HRESULT res) {
-    if (res != 0) throw std::runtime_error(std::to_string(res));
+    if (FAILED(res)) throw SimException(res);
 };
 
 Sim::Sim(const std::string &app_name) {
